package Acme::Version::Negative;

use 5.006;
use strict;
use warnings;

=head1 NAME

Acme::Version::Negative - Module for testing CPAN Pause indexing

=head1 VERSION

Version -2.00

=cut

our $VERSION = '-2.00';

1; # End of Acme::Version::Negative
